local VERSION = tonumber(("$Revision: 42454 $"):match("%d+"))

Parrot = AceLibrary("AceAddon-2.0"):new("AceDB-2.0", "AceEvent-2.0", "AceConsole-2.0", "FuBarPlugin-2.0", "Parser-3.0", "AceModuleCore-2.0")
local Parrot, self = Parrot, Parrot
Parrot.version = "r" .. VERSION
Parrot.revision = VERSION
Parrot.date = ("$Date: 2007-07-01 21:52:40 -0400 (Sun, 01 Jul 2007) $"):match("%d%d%d%d%-%d%d%-%d%d")

local waterfall = AceLibrary:HasInstance("Waterfall-1.0") and AceLibrary("Waterfall-1.0")

local _G = _G

local localeTables = {}
function Parrot:L(name)
	if not localeTables[name] then
		localeTables[name] = setmetatable({}, {__index = function(self, key)
			self[key] = key
			return key
		end})
	end
	return localeTables[name]
end

local L = Parrot:L("Parrot")

local SharedMedia = AceLibrary("SharedMedia-1.0")

Parrot:RegisterDB("ParrotDB")
Parrot:RegisterDefaults('profile', {
	font = "Friz Quadrata TT",
	fontSize = 20,
})

-- FuBar configuration
Parrot.hasIcon = [[Interface\Icons\Spell_Nature_ForceOfNature]]
Parrot.hideWithoutStandby = true
Parrot.defaultPosition = "MINIMAP"
Parrot.defaultMinimapPosition = 250
Parrot.hasNoText = true
Parrot.hasNoColor = true
Parrot.cannotDetachTooltip = true
Parrot.independentProfile = true
Parrot.blizzardTooltip = true

function Parrot:OnInitialize()
	self:RegisterChatCommand('/Parrot', '/Cow', {
		type = 'execute',
		func = function()
			self:OpenMenu()
		end
	})
end

local ParrotFrame

function Parrot:OnEnable()
	if not ParrotFrame then
		ParrotFrame = CreateFrame("Frame", "ParrotFrame", UIParent)
		ParrotFrame:SetFrameStrata("HIGH")
		ParrotFrame:SetToplevel(true)
		ParrotFrame:SetPoint("CENTER", 0, 60)
		ParrotFrame:SetWidth(24)
		ParrotFrame:SetHeight(24)
	end
end

function Parrot:OnDisable()
end

function Parrot:OnClick()
	if waterfall then
		waterfall:Open("Parrot")
	else
		self:Print(L["Waterfall-1.0 is required to access the GUI."])
	end
end

local freeFontStrings = {}
local wildFontStrings = {}
local fontString_num = 0
function Parrot:ShowMessage(text)
	if not self:IsActive() then
		return
	end
	local fs = next(freeFontStrings)
	if fs then
		fs:Show()
		freeFontStrings[fs] = nil
	else
		fontString_num = fontString_num + 1
		fs = ParrotFrame:CreateFontString("ParrotFrameFontString" .. fontString_num, "ARTWORK", "MasterFont")
	end
	
	fs:SetFont(SharedMedia:Fetch('font', self.db.profile.font), self.db.profile.fontSize)
	fs:SetPoint("BOTTOM", 0, 0)
	fs:SetText(text)
	fs.start = GetTime()
	wildFontStrings[fs] = true
	
	self:ScheduleRepeatingEvent("Parrot_OnUpdate", self.OnUpdate, 0, self)
end

function Parrot.modulePrototype:ShowMessage(text)
	Parrot:ShowMessage(text)
end

function Parrot:OnUpdate()
	local now = GetTime()
	for fs in pairs(wildFontStrings) do
		if fs.start + 2 <= now then
			fs:Hide()
			wildFontStrings[fs] = nil
			freeFontStrings[fs] = true
		else
			fs:SetPoint("BOTTOM", 0, (now - fs.start)*100)
		end
	end
	if not next(wildFontStrings) then
		self:CancelScheduledEvent("Parrot_OnUpdate")
	end
end

Parrot.options = {
	type = 'group',
	handler = Parrot,
	args = {
	}
}

if waterfall then
	waterfall:Register("Parrot", 
						"aceOptions", Parrot.options,
						"title", L["Parrot Configuration"],
						"treeLevels", 5);
end

Parrot.OnMenuRequest = Parrot.options

function Parrot:OnTooltipUpdate()
	GameTooltip:AddLine("Parrot")
	GameTooltip:AddLine(" ")
	if waterfall then
		GameTooltip:AddLine(L["|cffffff00Left-Click|r to change settings with a nice GUI configuration."], 0.2, 1, 0.2)
	end
	GameTooltip:AddLine(L["|cffffff00Right-Click|r to change settings with a drop-down menu."], 0.2, 1, 0.2)
end
